import java.awt.Shape;
import java.awt.geom.GeneralPath;
import java.util.ArrayList;

/**
 * Eine Tischgruppe, die manipuliert werden kann und sich selbst auf einer Leinwand zeichnet.
 * @author Claus Albowski
 * @version  2.1 (aug'06)
 */
public class Tischgruppe extends Moebel
{
  private ArrayList<Moebel> elemente;
  private int anzahl;

  /**
   * Erzeuge eine neue Tischgruppe mit einer Standardfarbe und Standardgroesse
   * an einer Standardposition.
   * Der Konstruktor muss die Zahl der Stuehle an der Laengskante uebergeben bekommen.
   */
    public Tischgruppe(int anzahl)
  {
    xPosition = 40;
    yPosition = 80;
    farbe = "blau";
    orientierung = 0;
    istSichtbar = false;
    int schrankbreite = 60;
    this.anzahl = anzahl;
    breite = 110+50*anzahl;
    tiefe  = 110;
    // Definition der Sammlung
    elemente = new ArrayList();
    for (int i=0;i<anzahl;i++){
        // Stuehle an der oberen Kante
        elemente.add(new Stuhl(60 + i*(40+10), 0, farbe, 0));
        // Stuehle an der unteren Kante
        elemente.add(new Stuhl(60 + i*(40+10), 120, farbe, 180));
    }
    // der Stuhl links
    elemente.add(new Stuhl(0, 60, farbe, 270));
    // der Tisch
    elemente.add(new Tisch(50, 50, farbe, 0, 10+anzahl*50, 60));
    // der Stuhl rechts
    elemente.add(new Stuhl(170, 60, farbe, 90));    
  }
  
  /**
   * Berechnet das zu zeichnende Shape anhand der gegebenen Daten
   */
  protected Shape gibAktuelleFigur()
  {
      GeneralPath tischgruppe = new GeneralPath();
      for (Moebel moebel:elemente)
        tischgruppe.append(moebel.gibAktuelleFigur(), false);      
      return  transformiere(tischgruppe);
  }
  
}
